@@ -1,6 +1,6 @@
 // This may look like C code, but it's really -*- C++ -*-
 /*
- * Copyright (C) 2008 Emweb bvba, Kessel-Lo, Belgium.
+ * Copyright (C) 2008 Emweb bv, Herent, Belgium.
  *
  * See the LICENSE file for terms of use.
  */
@@ -49,10 +49,10 @@ namespace Wt {
  * \code
  * // create the stack where the contents will be located
  * WStackedWidget contents = new WStackedWidget(contentsParent);
- *		 
+ *
  * // create a menu
  * WMenu menu = new WMenu(contents);
- *		 
+ *
  * // add four items using the default lazy loading policy.
  * menu.addItem("Introduction", new WText("intro"));
  * menu.addItem("Download", new WText("Not yet available"));
@@ -61,7 +61,7 @@ namespace Wt {
  * \endcode
  * \endif
  *
- * After contruction, the first entry will be selected. At any time,
+ * After construction, the first entry will be selected. At any time,
  * it is possible to select a particular item using select().
  *
  * Each item of %WMenu may be closeable (see WMenuItem::setCloseable(bool).
@@ -81,8 +81,7 @@ namespace Wt {
  * which lets menu items correspond to internal URLs, see
  * setInternalPathEnabled().
  *
- * The layout of the menu may be Orientation::Horizontal or Orientation::Vertical. The look of
- * the items may be defined through style sheets. The default
+ * The look of the items may be defined through style sheets. The default
  * WMenuItem implementation uses four style classes to distinguish
  * between inactivated, activated, closeable inactivated and closeable
  * activated menu items: <tt>"item"</tt>, <tt>"itemselected"</tt>,
@@ -94,7 +93,7 @@ namespace Wt {
  *
  * <h3>CSS</h3>
  *
- * The menu is rendered as a &gt;ul&lt;. Unless you use the bootstrap
+ * The menu is rendered as a &lt;ul&gt;. Unless you use the bootstrap
  * theme, you will want to customize the menu using inline or external
  * styles to hide the bullets and provide the appropriate horizontal
  * or vertical layout.
@@ -137,9 +136,9 @@ public:
    * \sa addItem(WMenuItem *)
    */
   WMenuItem *addItem(const WString& label,
-		     std::unique_ptr<WWidget> contents = nullptr,
-		     ContentLoading policy 
-		       = ContentLoading::Lazy);
+                     std::unique_ptr<WWidget> contents = nullptr,
+                     ContentLoading policy
+                       = ContentLoading::Lazy);
 
   /*! \brief Adds an item.
    *
@@ -157,9 +156,9 @@ public:
    * \sa addItem(WMenuItem *)
    */
   WMenuItem *addItem(const std::string& iconPath, const WString& label,
-		     std::unique_ptr<WWidget> contents = nullptr,
-		     ContentLoading policy 
-		       = ContentLoading::Lazy);
+                     std::unique_ptr<WWidget> contents = nullptr,
+                     ContentLoading policy
+                       = ContentLoading::Lazy);
 
     /*! \brief Adds an item with given text, and specify a slot method to be
    *         called when the item is triggered.
@@ -171,7 +170,7 @@ public:
    */
   template<class T, class V>
     WMenuItem *addItem(const WString& text, T *target, void (V::*method)());
-    
+
   /*! \brief Adds an item with given text and icon, and specify a slot
    *         method to be called when activated.
    *
@@ -184,7 +183,7 @@ public:
    */
   template<class T, class V>
     WMenuItem *addItem(const std::string& iconPath, const WString& text,
-		       T *target, void (V::*method)());
+                       T *target, void (V::*method)());
 
   /*! \brief Adds a submenu, with given text.
    *
@@ -203,7 +202,7 @@ public:
    * \sa add(WMenuItem *)
    */
   WMenuItem *addMenu(const std::string& iconPath, const WString& text,
-		     std::unique_ptr<WMenu> menu);
+                     std::unique_ptr<WMenu> menu);
 
   /*! \brief Adds an item.
    *
@@ -225,9 +224,9 @@ public:
    * \sa insertItem(int index, WMenuItem *)
    */
   WMenuItem *insertItem(int index, const WString& label,
-			std::unique_ptr<WWidget> contents = nullptr,
-			ContentLoading policy
-			  = ContentLoading::Lazy);
+                        std::unique_ptr<WWidget> contents = nullptr,
+                        ContentLoading policy
+                          = ContentLoading::Lazy);
 
   /*! \brief inserts an item.
    *
@@ -246,9 +245,9 @@ public:
    */
   WMenuItem *insertItem(int index, const std::string& iconPath,
                         const WString& label,
-			std::unique_ptr<WWidget> contents = nullptr,
-			ContentLoading policy
-			  = ContentLoading::Lazy);
+                        std::unique_ptr<WWidget> contents = nullptr,
+                        ContentLoading policy
+                          = ContentLoading::Lazy);
 
     /*! \brief inserts an item with given text, and specify a slot method to be
    *         called when the item is triggered.
@@ -284,7 +283,7 @@ public:
    * \sa insert(int index, WMenuItem *)
    */
   WMenuItem *insertMenu(int index, const WString& text,
-			std::unique_ptr<WMenu> menu);
+                        std::unique_ptr<WMenu> menu);
 
   /*! \brief inserts a submenu, with given icon and text.
    *
@@ -295,7 +294,7 @@ public:
    */
   WMenuItem *insertMenu(int index, const std::string& iconPath,
                         const WString& text,
-			std::unique_ptr<WMenu> menu);
+                        std::unique_ptr<WMenu> menu);
 
   /*! \brief Inserts an item.
    *
@@ -326,7 +325,7 @@ public:
 
   /*! \brief Selects an item.
    *
-   * SelectionFlag::Select the menu item \p item.
+   * Select the menu item \p item.
    *
    * When \p item is \c 0, the current selection is removed.
    *
@@ -625,7 +624,6 @@ private:
   int previousStackIndex_;
   bool needSelectionEventUpdate_;
 
-  void init();
   void updateItemsInternalPath();
   void itemPathChanged(WMenuItem *item);
   void selectVisual(WMenuItem *item);
@@ -646,7 +644,7 @@ WMenuItem *WMenu::addItem(const WString& text, T *target, void (V::*method)())
 
 template<class T, class V>
 WMenuItem *WMenu::addItem(const std::string& iconPath, const WString& text,
-			  T *target, void (V::*method)())
+                          T *target, void (V::*method)())
 {
   WMenuItem *item = addItem(iconPath, text);
   item->triggered().connect(target, method);
